package http_model

type SelectionSquareCondition struct {
	ProductType int16 `condition:"product_type"` // 商品类型
	Platform    int16 `condition:"platform"`     // 社媒平台
	SampleMode  int16 `condition:"sample_mode"`  // 领样形式
	TaskMode    int16 `condition:"task_mode"`    // 任务形式
}

type GetAllSelectionRequest struct {
	PageSize    int64 `json:"page_size"`
	PageNum     int64 `json:"page_num"`
	ProductType int16 `json:"product_type"` // 商品类型
	Platform    int16 `json:"platform"`     // 社媒平台
	SampleMode  int16 `json:"sample_mode"`  // 领样形式
	TaskMode    int16 `json:"task_mode"`    // 任务形式
}

type SelectionBriefInfo struct {
	SelectionId     string  `json:"selection_id"`
	SelectionName   string  `json:"selection_name"`   // 项目名称
	Platform        int     `json:"platform"`         // 社媒平台，1-7分别表示小红书、抖音、微博、快手、b站、大众点评、知乎
	EstimatedIncome float64 `json:"estimated_income"` // 预估赚金额，计算方式：商品售价×佣金比例
	ProductPrice    float64 `json:"product_price"`    // 售价
	CommissionRate  float64 `json:"commission_rate"`  // 佣金比例，百分之
	TaskReward      float64 `json:"task_reward"`      // 额外悬赏
	SampleMode      int     `json:"sample_mode"`      // 领样形式，1、2、3分别表示免费领样、垫付领样、不提供样品
	TaskMode        int     `json:"task_mode"`        // 任务形式，1、2分别表示悬赏任务、纯佣带货
	PlatformIcon    string  `json:"platform_icon"`    // 平台logo
	PhotoUrl        string  `json:"photo_url"`
}

type SelectionBriefInfoPreview struct {
	SelectionBriefInfo []*SelectionBriefInfo `json:"selection_brief_info"`
	Total              string                `json:"total"`
}

func NewGetAllSelectionRequest() *GetAllSelectionRequest {
	return new(GetAllSelectionRequest)
}

func NewGetAllSelectionResponse() *CommonResponse {
	resp := new(CommonResponse)
	resp.Data = new(SelectionBriefInfoPreview)
	return resp
}
